@@ -58,7 +58,7 @@ class GIFRequest(object):
             post = query_string
 
         headers = {}
-        headers['Host'] = self.config.endpoint.split('/')[0]
+        headers['Host'] = self.config.endpoint.split('/')[2]
         headers['USER_AGENT'] = self.user_agent
         headers['X_FORWARDED_FOR'] = self.x_forwarded_for
 
@@ -70,7 +70,7 @@ class GIFRequest(object):
         utils.pyga_logger(url)
         if post:
             utils.pyga_logger(post)
-        return urllib2.Request(url, post) #, headers)
+        return urllib2.Request(url, post, headers)
 
     def build_parameters(self):
         '''Marker implementation'''
@@ -82,12 +82,11 @@ class GIFRequest(object):
 
         #  Do not actually send the request if endpoint host is set to null
         if self.config.endpoint:
-            print request
-            print self.config.request_timeout
             try:
                 response = urllib2.urlopen(request, timeout=self.config.request_timeout)
             except Exception, e:
-                print e.headers, e.msg, e.url
+                utils.pyga_logger(e)
+                utils.pyga_logger("error with request")
 
         return response
 
@@ -128,9 +127,6 @@ class Request(GIFRequest):
         self.visitor = visitor
         self.session = session
 
-    def get_type(self):
-        return ''
-
     def build_http_request(self):
         self.x_forwarded_for = self.visitor.ip_address
         self.user_agent = self.visitor.user_agent
@@ -140,7 +136,7 @@ class Request(GIFRequest):
 
         #http://code.google.com/intl/de-DE/apis/analytics/docs/tracking/eventTrackerGuide.html#implementationConsiderations
         if self.session.track_count > 500:
-            pyga_logger('Google Analytics does not guarantee to process more than 500 requests per session.')
+            utils.pyga_logger('Google Analytics does not guarantee to process more than 500 requests per session.')
 
         if self.tracker.campaign:
             self.tracker.campaign.response_count = self.tracker.campaign.response_count + 1
@@ -194,7 +190,7 @@ class Request(GIFRequest):
 
         if custom_vars:
             if len(custom_vars) > 5:
-                pyga_logger('The sum of all custom variables cannot exceed 5 in any given request.')
+                utils.pyga_logger('The sum of all custom variables cannot exceed 5 in any given request.')
 
             x10 = X10()
             x10.clear_key(self.X10_CUSTOMVAR_NAME_PROJECT_ID)
@@ -287,7 +283,7 @@ class ItemRequest(Request):
         self.item = item
 
     def get_type(self):
-        ItemRequest.TYPE_ITEM
+        return ItemRequest.TYPE_ITEM
 
     def build_parameters(self):
         params = super(ItemRequest, self).build_parameters()
@@ -322,7 +318,7 @@ class PageViewRequest(Request):
         self.page = page
 
     def get_type(self):
-        PageViewRequest.TYPE_PAGE
+        return PageViewRequest.TYPE_PAGE
 
     def build_parameters(self):
         params = super(PageViewRequest, self).build_parameters()
@@ -358,7 +354,7 @@ class EventRequest(Request):
         self.event = event
 
     def get_type(self):
-        EventRequest.TYPE_EVENT
+        return EventRequest.TYPE_EVENT
 
     def build_parameters(self):
         params = super(EventRequest, self).build_parameters()
@@ -389,7 +385,7 @@ class SocialInteractionRequest(Request):
         self.page = page
 
     def get_type(self):
-        SocialInteractionRequest.TYPE_SOCIAL
+        return SocialInteractionRequest.TYPE_SOCIAL
 
     def build_parameters(self):
         params = super(SocialInteractionRequest, self).build_parameters()
@@ -410,7 +406,7 @@ class TransactionRequest(Request):
         self.transaction =  transaction
 
     def get_type(self):
-        TransactionRequest.TYPE_TRANSACTION
+        return TransactionRequest.TYPE_TRANSACTION
 
     def build_parameters(self):
         params = super(TransactionRequest, self).build_parameters()
@@ -487,7 +483,7 @@ class Config(object):
     def __setattr__(self, name, value):
         if name == 'site_speed_sample_rate':
             if value and (value < 0 or value >100):
-                pyga_logger('For consistency with ga.js, sample rates must be specified as a number between 0 and 100.')
+                utils.pyga_logger('For consistency with ga.js, sample rates must be specified as a number between 0 and 100.')
         object.__setattr__(self, name, value)
 
 
@@ -587,30 +583,30 @@ class Parameters(object):
     def __init__(self):
         # General Parameters
         self.utmwv = Tracker.VERSION
-        self.utmac = None
-        self.utmhn = None
-        self.utmt = None
-        self.utms = None
-        self.utmn = None
-        self.utmcc = None
-        self.utme = None
-        self.utmni = None
-        self.aip = None
-        self.utmu = None
+        self.utmac = ''
+        self.utmhn = ''
+        self.utmt = ''
+        self.utms = ''
+        self.utmn = ''
+        self.utmcc = ''
+        self.utme = ''
+        self.utmni = ''
+        self.aip = ''
+        self.utmu = ''
 
         # Page Parameters
-        self.utmp = None
-        self.utmdt = None
+        self.utmp = ''
+        self.utmdt = ''
         self.utmcs = '-'
         self.utmr = '-'
 
         # Visitor Parameters
-        self.utmip = None
-        self.utmul = None
+        self.utmip = ''
+        self.utmul = ''
         self.utmfl = '-'
         self.utmje = '-'
-        self.utmsc = None
-        self.utmsr = None
+        self.utmsc = ''
+        self.utmsr = ''
         '''
         Visitor tracking cookie __utma
 
@@ -627,10 +623,10 @@ class Parameters(object):
         Expiration: 2 years from set/update.
         Format: __utma=<domainHash>.<uniqueId>.<firstTime>.<lastTime>.<currentTime>.<sessionCount>
         '''
-        self._utma = None
+        self._utma = ''
 
         # Session Parameters
-        self.utmhid = None
+        self.utmhid = ''
         '''
         Session timeout cookie parameter __utmb
 
@@ -651,7 +647,7 @@ class Parameters(object):
         Format: __utmb=<domainHash>.<trackCount>.<token>.<lastTime>
 
         '''
-        self._utmb = None
+        self._utmb = ''
         '''
         Session tracking cookie parameter __utmc
 
@@ -671,33 +667,33 @@ class Parameters(object):
         Format: __utmc=<domainHash>
 
         '''
-        self._utmc = None
-        self.utmipc = None
-        self.utmipn = None
-        self.utmipr = None
-        self.utmiqt = None
-        self.utmiva = None
-        self.utmtid = None
-        self.utmtst = None
-        self.utmtto = None
-        self.utmttx = None
-        self.utmtsp = None
-        self.utmtci = None
-        self.utmtrg = None
-        self.utmtco = None
+        self._utmc = ''
+        self.utmipc = ''
+        self.utmipn = ''
+        self.utmipr = ''
+        self.utmiqt = ''
+        self.utmiva = ''
+        self.utmtid = ''
+        self.utmtst = ''
+        self.utmtto = ''
+        self.utmttx = ''
+        self.utmtsp = ''
+        self.utmtci = ''
+        self.utmtrg = ''
+        self.utmtco = ''
 
         # Campaign Parameters
-        self.utmcn = None
-        self.utmcr = None
-        self.utmcid = None
-        self.utmcsr = None
-        self.utmgclid = None
-        self.utmdclid = None
-        self.utmccn = None
-        self.utmcmd = None
-        self.utmctr = None
-        self.utmcct = None
-        self.utmcvr = None
+        self.utmcn = ''
+        self.utmcr = ''
+        self.utmcid = ''
+        self.utmcsr = ''
+        self.utmgclid = ''
+        self.utmdclid = ''
+        self.utmccn = ''
+        self.utmcmd = ''
+        self.utmctr = ''
+        self.utmcct = ''
+        self.utmcvr = ''
         '''
         Campaign tracking cookie parameter.
 
@@ -712,12 +708,12 @@ class Parameters(object):
         Format: __utmz=<domainHash>.<campaignCreation>.<campaignSessions>.<responseCount>.<campaignTracking>
 
         '''
-        self._utmz = None
+        self._utmz = ''
 
         # Social Tracking Parameters
-        self.utmsn = None
-        self.utmsa = None
-        self.utmsid = None
+        self.utmsn = ''
+        self.utmsa = ''
+        self.utmsid = ''
 
         # Google Website Optimizer (GWO) parameters
         '''
@@ -729,7 +725,7 @@ class Parameters(object):
 
         Expiration: 2 years from set/update.
         '''
-        self._utmx = None
+        self._utmx = ''
 
         # Custom Variables parameters (deprecated)
         '''
@@ -747,7 +743,7 @@ class Parameters(object):
         Format: __utmv=<domainHash>.<value>
 
         '''
-        self._utmv = None
+        self._utmv = ''
 
     def get_parameters(self):
         '''
@@ -759,7 +755,7 @@ class Parameters(object):
         for attr in attribs:
             if attr[0] != '_':
                 val = getattr(self, attr)
-                if val != None:
+                if val:
                     params[attr] = val
 
         return params
@@ -803,7 +799,7 @@ class Tracker(object):
     def __setattr__(self, name, value):
         if name == 'account_id':
             if value and not utils.is_valid_google_account(value):
-                pyga_logger('Given Google Analytics account ID is not valid')
+                utils.pyga_logger('Given Google Analytics account ID is not valid')
 
         elif name == 'campaign':
             if isinstance(value, Campaign):
@@ -909,7 +905,7 @@ class Tracker(object):
             stderr.flush()
         elif error_severity == Tracker.ERROR_SEVERITY_RAISE:
             # TODO: Log
-            pyga_logger(message)
+            utils.pyga_logger(message)
         else:
             # TODO: Log
             pass
